@@ -441,7 +441,7 @@ spa_pod_builder_push_sequence(struct spa_pod_builder *builder, struct spa_pod_fr
 	return res;
 }
 
-static inline uint32_t
+static inline int
 spa_pod_builder_control(struct spa_pod_builder *builder, uint32_t offset, uint32_t type)
 {
 	const struct { uint32_t offset; uint32_t type; } p = { offset, type };
@@ -481,7 +481,7 @@ do {										\
 		spa_pod_builder_long(builder, va_arg(args, int64_t));		\
 		break;								\
 	case 'f':								\
-		spa_pod_builder_float(builder, va_arg(args, double));		\
+		spa_pod_builder_float(builder, (float)va_arg(args, double));	\
 		break;								\
 	case 'd':								\
 		spa_pod_builder_double(builder, va_arg(args, double));		\
